@@ -206,16 +206,9 @@ property_descriptions = {
         dontsearch=True,
         copyable=True,
     ),
-    'univentionObjectIdentifier': univention.admin.property(
-        short_description=_('Immutable Object Identifier'),
-        long_description=_('Immutable attribute to track the identity of an object in UDM'),
-        syntax=univention.admin.syntax.string,
-        may_change=False,
-        dontsearch=True,
-    ),
     'univentionSourceIAM': univention.admin.property(
         short_description=_('Immutable Identifier of the source IAM'),
-        long_description=_('Immutable attribute to identfy source IAM'),
+        long_description=_('Immutable attribute referencing the name of the source IAM'),
         syntax=univention.admin.syntax.string,
         may_change=False,
         dontsearch=True,
@@ -278,7 +271,6 @@ mapping.register('sambaPrivileges', 'univentionSambaPrivilegeList', encoding='AS
 mapping.register('allowedEmailUsers', 'univentionAllowedEmailUsers')
 mapping.register('allowedEmailGroups', 'univentionAllowedEmailGroups')
 mapping.registerUnmapping('sambaRID', unmapSambaRid)
-mapping.register('univentionObjectIdentifier', 'univentionObjectIdentifier', None, univention.admin.mapping.ListToString)
 mapping.register('univentionSourceIAM', 'univentionSourceIAM', None, univention.admin.mapping.ListToString)
 register_member_role_mapping(mapping)
 
@@ -489,11 +481,6 @@ class object(univention.admin.handlers.simpleLdap):
         else:
             self['gidNumber'] = self.request_lock('gidNumber')
 
-        if self['univentionObjectIdentifier']:
-            univention.admin.allocators.acquireUnique(self.lo, self.position, 'univentionObjectIdentifier', self['univentionObjectIdentifier'], 'univentionObjectIdentifier', scope='base')
-            # "False" ==> do not update univentionLastUsedValue in LDAP if a specific value has been specified
-            self.alloc.append(('univentionObjectIdentifier', self['univentionObjectIdentifier'], False))
-
         self.check_for_group_recursion()
         self._check_uid_gid_uniqueness()
 
